@@ -68,14 +68,6 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
 
     supportedImageFormats();
 
-
-    ui->comboBoxVideoCodec->setVisible( false );
-    ui->comboBoxFormat->setVisible( false );
-
-    // Inhalt von tab Video in Tab 1 verschieben und Tab Video ausblenden
-    ui->verticalLayout_8->insertWidget( 0, ui->widget );
-    ui->tabWidgetScreencast->removeTab(1);
-
     QFile fileCSS( ":/pictures/css/css.qss" );
     fileCSS.open( QFile::ReadOnly | QFile::Text );
     QTextStream streamCSS( &fileCSS );
@@ -105,7 +97,11 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
     connect( this, SIGNAL( signal_beginRecordTime(QString) ),  vkInformation, SLOT( slot_beginRecordTime(QString) ) );
     set_RegionChoice();
     set_Connects();
-    set_check_all_Elements_available();
+    set_check_screencast_elements_available();
+    set_check_GIF_convert_elements_available();
+    set_check_MP4_convert_elements_available();
+    set_check_WEBM_convert_elements_available();
+
     vkContainerController_wl = new QvkContainerController_wl( ui );
 
     QvkAudioController_wl *vkAudioController = new QvkAudioController_wl( ui );
@@ -153,7 +149,6 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
     if ( !screen.empty() ) {
         for ( int i = 0; i < screen.size(); i++ ) {
             if ( screen.at(i)->name() == QGuiApplication::primaryScreen()->name() ) {
-                qDebug();
                 qDebug().noquote() << global::nameOutput << "This screen is the primary screen: " << QGuiApplication::primaryScreen()->name();
             } else {
                 qDebug().noquote() << global::nameOutput << "Name from screen: " << screen.at(i)->name();
@@ -171,13 +166,15 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
         }
     }
 
+    vkSystray = new QvkSystray_wl( ui );
+    if ( QSystemTrayIcon::isSystemTrayAvailable() == true ) {
+        vkSystray->init();
+        connect( ui->checkBoxShowInSystray, SIGNAL( clicked(bool) ),              vkSystray, SLOT( setVisible(bool) ) );
+        connect( vkSystray,                 SIGNAL( signal_SystemtrayIsClose() ), this,      SLOT( close() ) );
+    }
+
     vkSettings.readAll( ui, this );
 
-    connect( ui->pushButton_log_refresh, SIGNAL( clicked(bool) ), this, SLOT( slot_log_refresh() ) );
-
-    // Beim Start wird immer der selbe Tab geöffnet
-    ui->toolButtonScreencast->click();
-
     ui->widgetLanguageAndHelp->setVisible( false );
  }
 
@@ -204,6 +201,7 @@ void QvkMainWindow_wl::closeEvent( QCloseEvent *event )
     ui->pushButtonStop->click();
     vkRegionChoise_wl->close();
     vkSettings.saveAll( ui, this );
+    vkSystray->deleteLater();
 
     qDebug().noquote() << global::nameOutput << "QvkMainWindow_wl::closeEvent End close";
 }
@@ -307,6 +305,11 @@ void QvkMainWindow_wl::get_system_info()
             ui->toolButton_area_left->hide();
         }
     }
+    if ( QSystemTrayIcon::isSystemTrayAvailable() == true ) {
+        qDebug().noquote() << global::nameOutput << "Systray: Supported";
+    } else {
+        qDebug().noquote() << global::nameOutput << "Systray: Not supported";
+    }
     qDebug().noquote() << global::nameOutput << "Icon-Theme:" << QIcon::themeName();
     qDebug().noquote() << global::nameOutput << "Styles:" << QStyleFactory::keys();
     qDebug().noquote() << global::nameOutput << "Qt-PluginsPath:     " << QLibraryInfo::path( QLibraryInfo::PluginsPath );
@@ -360,17 +363,20 @@ void QvkMainWindow_wl::set_Connects()
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->toolButtonScreencastAreaReset,   SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_video,                     SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_audio,                     SLOT( setEnabled(bool) ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), ui->frame_3,                         SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStart, SIGNAL( clicked(bool) ), this,                                SLOT( slot_portal_start() ) );
 
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), this,                                SLOT( slot_stop() ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->pushButtonStop,                  SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->pushButtonStart,                 SLOT( setDisabled(bool) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->pushButtonPause,                 SLOT( setEnabled(bool) ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->radioButtonScreencastFullscreen, SLOT( setDisabled(bool) ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->radioButtonScreencastWindow,     SLOT( setDisabled(bool) ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->radioButtonScreencastArea,       SLOT( setDisabled(bool) ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->frameVideoPath,                  SLOT( setDisabled(bool) ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->frame_video,                     SLOT( setDisabled(bool) ) );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->frame_audio,                     SLOT( setDisabled(bool) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), ui->frame_3,                         SLOT( setDisabled(bool) ) );
     connect( ui->pushButtonStop,  &QPushButton::clicked, this, [=]() {
         if ( ui->radioButtonScreencastArea->isChecked() == true ) {
             ui->frame_area->setEnabled( true );
@@ -379,6 +385,21 @@ void QvkMainWindow_wl::set_Connects()
     } );
     connect( ui->pushButtonStop,  SIGNAL( clicked(bool) ), portal_wl,                           SLOT( slot_stopScreenCast() ) );
 
+    connect( ui->pushButtonPause, SIGNAL( clicked(bool) ), this,                   SLOT( slot_Pause() ) );
+    connect( ui->pushButtonPause, SIGNAL( clicked(bool) ), ui->pushButtonPause,    SLOT( hide() ) );
+    connect( ui->pushButtonPause, SIGNAL( clicked(bool) ), ui->pushButtonContinue, SLOT( show() ) );
+    connect( ui->pushButtonPause, SIGNAL( clicked(bool) ), ui->pushButtonStop,     SLOT( setEnabled(bool) ) );
+    connect( ui->pushButtonPause, SIGNAL( clicked(bool) ), ui->pushButtonContinue, SLOT( setDisabled(bool) ) );
+
+    connect( ui->pushButtonContinue, SIGNAL( clicked(bool) ), this,                   SLOT( slot_Continue() ) );
+    connect( ui->pushButtonContinue, SIGNAL( clicked(bool) ), ui->pushButtonContinue, SLOT( setEnabled(bool) ) );
+    connect( ui->pushButtonContinue, SIGNAL( clicked(bool) ), ui->pushButtonContinue, SLOT( hide() ) );
+    connect( ui->pushButtonContinue, SIGNAL( clicked(bool) ), ui->pushButtonPause,    SLOT( show() ) );
+    connect( ui->pushButtonContinue, SIGNAL( clicked(bool) ), ui->pushButtonStop,     SLOT( setDisabled(bool) ) );
+    ui->pushButtonContinue->hide();
+
+    connect( ui->pushButtonOpenfolder, SIGNAL( clicked(bool) ), this, SLOT( slot_folder() ) );
+
     connect( ui->radioButtonScreencastFullscreen, SIGNAL( clicked(bool) ), ui->toolButtonScreencastAreaReset, SLOT( setDisabled(bool) ) );
     connect( ui->radioButtonScreencastWindow,     SIGNAL( clicked(bool) ), ui->toolButtonScreencastAreaReset, SLOT( setDisabled(bool) ) );
     connect( ui->radioButtonScreencastArea,       SIGNAL( clicked(bool) ), ui->toolButtonScreencastAreaReset, SLOT( setEnabled(bool) ) );
@@ -395,11 +416,10 @@ void QvkMainWindow_wl::set_Connects()
     connect( ui->toolButtonOpenh264Reset,       SIGNAL( clicked(bool) ), this, SLOT( slot_openh264Reset() ) );
 
     connect( ui->pushButtonSnapshot, SIGNAL( clicked(bool) ), this, SLOT( slot_snapshotHideBeforeRecording(bool) ) );
+    connect( ui->pushButtonSnapshotOpenFolder, SIGNAL( clicked(bool) ), this, SLOT( slot_path_to_snapshot_folder(bool) ) );
 
     connect( ui->pushButton_log_openfolder, SIGNAL( clicked(bool) ), this, SLOT( slot_log_folder() ) );
-
-    connect( ui->comboBoxVideoCodec, SIGNAL( currentTextChanged(QString) ), this, SLOT( slot_videoCodecChanged(QString) ) );
-
+    connect( ui->pushButton_log_refresh,    SIGNAL( clicked(bool) ), this, SLOT( slot_log_refresh() ) );
 }
 
 
@@ -448,8 +468,6 @@ void QvkMainWindow_wl::slot_handle_response_snapshot( uint responseCode, QVarian
         QFileInfo fileInfo( url.toLocalFile() );
         path_to_snapshot_folder = fileInfo.absolutePath();
         QString filePath_org = fileInfo.absoluteFilePath();
-        disconnect( ui->pushButtonSnapshotOpenFolder, nullptr, nullptr, nullptr );
-        connect( ui->pushButtonSnapshotOpenFolder, SIGNAL( clicked(bool) ), this, SLOT( slot_path_to_snapshot_folder(bool) ) );
 
         QPixmap pixmap = QPixmap( filePath_org );
         QString filePath_new = path_to_snapshot_folder +
@@ -469,6 +487,7 @@ void QvkMainWindow_wl::slot_handle_response_snapshot( uint responseCode, QVarian
         vkShowMessage_wl->set_Image( filePath_new );
         vkShowMessage_wl->set_timeOut( 10000 );
         vkShowMessage_wl->showMessage( "" );
+        vkShowMessage_wl->set_folderPath( path_to_snapshot_folder );
 
         qDebug().noquote() << global::nameOutput << "[Snapshot] Saved under:" << filePath_new;
     } else {
@@ -480,6 +499,11 @@ void QvkMainWindow_wl::slot_handle_response_snapshot( uint responseCode, QVarian
 void QvkMainWindow_wl::slot_path_to_snapshot_folder( bool bo )
 {
     Q_UNUSED(bo)
+
+    if ( path_to_snapshot_folder == "" ) {
+        path_to_snapshot_folder = QStandardPaths::writableLocation( QStandardPaths::PicturesLocation );
+    }
+
     if ( QDesktopServices::openUrl( QUrl( "file:///" + path_to_snapshot_folder, QUrl::TolerantMode ) ) == false ) {
         QPixmap pixmap( ":/pictures/status/information.png" );
         pixmap = pixmap.scaled( 64, 64, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
@@ -506,54 +530,6 @@ void QvkMainWindow_wl::supportedImageFormats()
 }
 
 
-QString QvkMainWindow_wl::get_Videocodec_Encoder()
-{
-    QString value;
-    QString encoder = ui->comboBoxVideoCodec->currentData().toString();
-
-    if ( encoder == "openh264enc" ) {
-        QStringList list;
-        list << encoder;
-        list << "qp-min=" + QString::number( sliderOpenh264->value() );
-        list << "qp-max=" + QString::number( sliderOpenh264->value() );
-        list << "usage-type=camera"; // We need camera not screen. With screen and a fast sequence of images the video jerks.
-        list << "complexity=low";
-        list << "multi-thread=" + QString::number( 0 );
-        list << "slice-mode=auto"; // Number of slices equal to number of threads
-        value = list.join( " " );
-        value.append( " ! h264parse" );
-    }
-
-    return value;
-}
-
-
-void QvkMainWindow_wl::slot_videoCodecChanged( QString codec )
-{
-    ui->frameVideoCodecOpenh264->setVisible( false );
-
-    if ( codec == "H.264" ) {
-        ui->frameVideoCodecOpenh264->setVisible( true );
-    }
-}
-
-
-QString QvkMainWindow_wl::get_Muxer()
-{
-    QString value = ui->comboBoxFormat->currentData().toString();
-    if ( ui->comboBoxFormat->currentData().toString() == "matroskamux" ) {
-        value = ui->comboBoxFormat->currentData().toString() + " name=mux writing-app=" + global::name + "_" + QString( global::version ).replace( " ", "_" );
-    } else {
-        value = ui->comboBoxFormat->currentData().toString() + " name=mux";
-    }
-
-    if ( ui->comboBoxFormat->currentData().toString() == "gifenc" ) {
-        value = "";
-    }
-
-    return value;
-}
-
 //------------------------------------------------
 //             pushButtonStart
 //                   |
@@ -676,6 +652,7 @@ void QvkMainWindow_wl::slot_pre_start( QString vk_fd, QString vk_path )
             ui->frameVideoPath->setEnabled( true );
             ui->frame_video->setEnabled( true );
             ui->frame_audio->setEnabled( true );
+            ui->frame_3->setEnabled( true );
 
             portal_wl->slot_stopScreenCast();
         }
@@ -701,6 +678,7 @@ QString QvkMainWindow_wl::Pipeline_structured_output( QString pipeline )
     return string;
 }
 
+
 QStringList QvkMainWindow_wl::VK_getSelectedAudioDevice()
 {
     QStringList list;
@@ -714,8 +692,8 @@ QStringList QvkMainWindow_wl::VK_getSelectedAudioDevice()
     return list;
 }
 
-QMessageBox *msgBox;
 
+QMessageBox *msgBox;
 //---------------------------------------------------------------------------------------------------
 GstBusSyncReply QvkMainWindow_wl::call_bus_message( GstBus *bus, GstMessage *message, gpointer user_data )
 {
@@ -761,6 +739,7 @@ GstBusSyncReply QvkMainWindow_wl::call_bus_message( GstBus *bus, GstMessage *mes
 void QvkMainWindow_wl::slot_start_gst( QString vk_fd, QString vk_path )
 {
     ui->pushButtonStop->setEnabled( true );
+    ui->pushButtonPause->setEnabled( true );
 
     QThread::msleep( static_cast<unsigned long>( sliderSecondWaitBeforeRecording->value()) * 1000 );
     qDebug().noquote() << global::nameOutput << "SecondWaitBeforeRecording:" << sliderSecondWaitBeforeRecording->value();
@@ -773,7 +752,19 @@ void QvkMainWindow_wl::slot_start_gst( QString vk_fd, QString vk_path )
     stringList << "queue max-size-bytes=1073741824 max-size-time=10000000000 max-size-buffers=1000";
     if ( ui->radioButtonScreencastArea->isChecked() ) { stringList << get_Area_Videocrop(); }
     stringList << "video/x-raw, framerate=" + QString::number( sliderFrames->value() ) + "/1";
-    stringList << get_Videocodec_Encoder();
+
+    QString value;
+    QStringList list;
+    list << "openh264enc" ;
+    list << "qp-min=" + QString::number( sliderOpenh264->value() );
+    list << "qp-max=" + QString::number( sliderOpenh264->value() );
+    list << "usage-type=camera"; // We need camera not screen. With screen and a fast sequence of images the video jerks.
+    list << "complexity=low";
+    list << "multi-thread=" + QString::number( 0 );
+    list << "slice-mode=auto"; // Number of slices equal to number of threads
+    value = list.join( " " );
+    value.append( " ! h264parse" );
+    stringList << value;
 
     // Only if one or more audiodevice is selected
     if ( ( VK_getSelectedAudioDevice().count() > 0 ) and ( ui->comboBoxAudioCodec->count() > 0 ) ) {
@@ -794,7 +785,6 @@ void QvkMainWindow_wl::slot_start_gst( QString vk_fd, QString vk_path )
         stringList << "mux.";
     }
 
-
     // Pipeline for more as one audiodevice
     if ( ( VK_getSelectedAudioDevice().count() > 1 ) and ( ui->comboBoxAudioCodec->count() > 0 ) )
     {
@@ -827,10 +817,10 @@ void QvkMainWindow_wl::slot_start_gst( QString vk_fd, QString vk_path )
         }
     }
 
-    stringList << get_Muxer();
+    stringList << "matroskamux name=mux writing-app=" + global::name + "_" + QString( global::version ).replace( " ", "_" );
     stringList.removeAll( "" );
 
-    QString newVideoFilename = global::name + "-" + QDateTime::currentDateTime().toString( "yyyy-MM-dd_hh-mm-ss" ) + "." + ui->comboBoxFormat->currentText();
+    QString newVideoFilename = global::name + "-" + QDateTime::currentDateTime().toString( "yyyy-MM-dd_hh-mm-ss" ) + ".mkv";
     stringList << "filesink location=\"" + ui->lineEditVideoPath->text() + "/" + newVideoFilename + "\"";
 
     QString VK_Pipeline = stringList.join( " ! " );
@@ -851,7 +841,7 @@ void QvkMainWindow_wl::slot_start_gst( QString vk_fd, QString vk_path )
     GError *error = Q_NULLPTR;
     pipeline = gst_parse_launch( line, &error );
 
-    // Da ist iergendwo ein Bug, stürzt bei STOP ab
+    // Da ist irgendwo ein Bug, stürzt bei STOP ab
 //    GstBus *bus = gst_pipeline_get_bus( GST_PIPELINE ( pipeline ) );
 //    gst_bus_set_sync_handler( bus, (GstBusSyncHandler)call_bus_message, this, NULL );
 //    gst_object_unref( bus );
@@ -944,10 +934,17 @@ void QvkMainWindow_wl::slot_portal_dialog_aborted()
     ui->frameVideoPath->setEnabled( true );
     ui->frame_video->setEnabled( true );
     ui->frame_audio->setEnabled( true );
+    ui->frame_3->setEnabled( true );
     if ( ui->radioButtonScreencastArea->isChecked() == true ) {
        ui->frame_area->setEnabled( true );
        ui->toolButtonScreencastAreaReset->setEnabled( true );
     }
+
+    vkSystray->startAction->setEnabled(true);
+    vkSystray->stopAction->setEnabled(false);
+    vkSystray->pauseAction->setEnabled(false);
+    vkSystray->continueAction->setEnabled(false);
+    vkSystray->slot_setSystrayIcon(true);
 }
 
 
@@ -969,7 +966,7 @@ void QvkMainWindow_wl::set_SpezialSliders()
     sliderFrames->setTracking( true );
     sliderFrames->setMinimum( 10 );
     sliderFrames->setMaximum( 60 );
-    sliderFrames->setValue( 25 );
+    sliderFrames->setValue( 0 );
     sliderFrames->show();
 
     sliderSecondWaitBeforeRecording = new QvkSpezialSlider( Qt::Horizontal );
@@ -1029,24 +1026,23 @@ void QvkMainWindow_wl::messageBox( QString value )
 }
 
 
-void QvkMainWindow_wl::set_check_all_Elements_available()
+void QvkMainWindow_wl::set_check_screencast_elements_available()
 {
     QStringList list;
     list << "pipewiresrc";
-    list << "pulsesrc";
-    list << "queue";
-    list << "capsfilter";
     list << "videoconvert";
     list << "videorate";
+    list << "queue";
+    list << "h264parse";
+    list << "pulsesrc";
     list << "audioconvert";
     list << "audiorate";
-    list << "filesink";
-    list << "videoscale";
-    list << "h264parse";
+    list << "audioresample";
     list << "audiomixer";
+    list << "filesink";
     list << "videocrop";
 
-    qDebug().noquote() << global::nameOutput << "--- GStreamer elements ---";
+    qDebug().noquote() << global::nameOutput << "--- Screencast: GStreamer elements ---";
 
     for ( int i = 0; i < list.count(); i++ ) {
         GstElementFactory *factory = gst_element_factory_find( QString( list.at(i) ).toLatin1() );
@@ -1064,6 +1060,92 @@ void QvkMainWindow_wl::set_check_all_Elements_available()
 }
 
 
+void QvkMainWindow_wl::set_check_GIF_convert_elements_available()
+{
+    QStringList list;
+    list << "filesrc";
+    list << "matroskademux";
+    list << "h264parse";
+    list << "openh264dec";
+    list << "queue";
+    list << "videoconvert";
+    list << "gifenc";
+    list << "filesink";
+
+    qDebug().noquote() << global::nameOutput << "--- Convert to GIF: GStreamer elements ---";
+
+    for ( int i = 0; i < list.count(); i++ ) {
+        GstElementFactory *factory = gst_element_factory_find( QString( list.at(i) ).toLatin1() );
+        if ( !factory ) {
+            qDebug().noquote() << global::nameOutput << "-" << list.at(i);
+        } else {
+            qDebug().noquote() << global::nameOutput << "+" << list.at(i);
+            gst_object_unref( factory );
+        }
+    }
+    qDebug();
+}
+
+
+void QvkMainWindow_wl::set_check_MP4_convert_elements_available()
+{
+    QStringList list;
+    list << "filesrc";
+    list << "matroskademux";
+    list << "h264parse";
+    list << "queue";
+    list << "mp4mux";
+    list << "filesink";
+    list << "mpegaudioparse";
+    list << "opusparse";
+
+    qDebug().noquote() << global::nameOutput << "--- Convert to MP4: GStreamer elements ---";
+
+    for ( int i = 0; i < list.count(); i++ ) {
+        GstElementFactory *factory = gst_element_factory_find( QString( list.at(i) ).toLatin1() );
+        if ( !factory ) {
+            qDebug().noquote() << global::nameOutput << "-" << list.at(i);
+        } else {
+            qDebug().noquote() << global::nameOutput << "+" << list.at(i);
+            gst_object_unref( factory );
+        }
+    }
+    qDebug();
+}
+
+
+void QvkMainWindow_wl::set_check_WEBM_convert_elements_available()
+{
+    QStringList list;
+    list << "filesrc";
+    list << "matroskademux";
+    list << "h264parse";
+    list << "openh264dec";
+    list << "queue";
+    list << "videoconvert";
+    list << "vp8enc";
+    list << "webmmux";
+    list << "filesink";
+    list << "uridecodebin";
+    list << "audioconvert";
+    list << "audiorate";
+    list << "vorbisenc";
+
+    qDebug().noquote() << global::nameOutput << "--- Convert to WEBM: GStreamer elements ---";
+
+    for ( int i = 0; i < list.count(); i++ ) {
+        GstElementFactory *factory = gst_element_factory_find( QString( list.at(i) ).toLatin1() );
+        if ( !factory ) {
+            qDebug().noquote() << global::nameOutput << "-" << list.at(i);
+        } else {
+            qDebug().noquote() << global::nameOutput << "+" << list.at(i);
+            gst_object_unref( factory );
+        }
+    }
+    qDebug();
+}
+
+
 void QvkMainWindow_wl::set_RegionChoice()
 {
     vkRegionChoise_wl = new QvkRegionChoise_wl( ui );
@@ -1117,6 +1199,21 @@ void QvkMainWindow_wl::slot_videoFileSystemWatcherSetNewPath()
 }
 
 
+void QvkMainWindow_wl::slot_folder()
+{
+    if ( QDesktopServices::openUrl( QUrl( "file:///" + ui->lineEditVideoPath->text(), QUrl::TolerantMode ) ) == false ) {
+        QPixmap pixmap( ":/pictures/status/information.png" );
+        pixmap = pixmap.scaled( 64, 64, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+
+        QMessageBox msgBox( this );
+        msgBox.setText( tr( "No filemanager found." ) + "\n" + tr( "Please install a filemanager." ) );
+        msgBox.setWindowTitle( global::name + " " + global::version );
+        msgBox.setIconPixmap( pixmap );
+        msgBox.exec();
+    }
+}
+
+
 void QvkMainWindow_wl::slot_log_folder()
 {
     QUrl url( vkLogController->get_log_filePath() );
@@ -1133,3 +1230,41 @@ void QvkMainWindow_wl::slot_log_folder()
         msgBox.exec();
     }
 }
+
+
+void QvkMainWindow_wl::slot_Pause()
+{
+    if ( ui->pushButtonStart->isEnabled() == false ) {
+        qDebug().noquote() << global::nameOutput << "Pause was clicked";
+        GstStateChangeReturn ret = gst_element_set_state( pipeline, GST_STATE_PAUSED );
+        if ( ret == GST_STATE_CHANGE_FAILURE )   { qDebug().noquote() << global::nameOutput << "Pause was clicked" << "GST_STATE_CHANGE_FAILURE" << "Returncode =" << ret;   } // 0
+        if ( ret == GST_STATE_CHANGE_SUCCESS )   { qDebug().noquote() << global::nameOutput << "Pause was clicked" << "GST_STATE_CHANGE_SUCCESS" << "Returncode =" << ret;   } // 1
+        if ( ret == GST_STATE_CHANGE_ASYNC )     { qDebug().noquote() << global::nameOutput << "Pause was clicked" << "GST_STATE_CHANGE_ASYNC" << "Returncode =" << ret;   }   // 2
+        if ( ret == GST_STATE_CHANGE_NO_PREROLL ){ qDebug().noquote() << global::nameOutput << "Pause was clicked" << "GST_STATE_CHANGE_NO_PREROLL" << "Returncode =" << ret; }// 3
+
+        /* wait until it's up and running or failed */
+        if (gst_element_get_state (pipeline, NULL, NULL, -1) == GST_STATE_CHANGE_FAILURE) {
+          g_error ("Failed to go into PAUSED state");
+        }
+
+    }
+}
+
+
+void QvkMainWindow_wl::slot_Continue()
+{
+    if ( ( ui->pushButtonStart->isEnabled() == false ) and ( ui->pushButtonContinue->isEnabled() == true ) ) {
+        GstStateChangeReturn ret = gst_element_set_state( pipeline, GST_STATE_PLAYING );
+        if ( ret == GST_STATE_CHANGE_FAILURE )   { qDebug().noquote() << global::nameOutput << "Continue was clicked" << "GST_STATE_CHANGE_FAILURE" << "Returncode =" << ret;   } // 0
+        if ( ret == GST_STATE_CHANGE_SUCCESS )   { qDebug().noquote() << global::nameOutput << "Continue was clicked" << "GST_STATE_CHANGE_SUCCESS" << "Returncode =" << ret;   } // 1
+        if ( ret == GST_STATE_CHANGE_ASYNC )     { qDebug().noquote() << global::nameOutput << "Continue was clicked" << "GST_STATE_CHANGE_ASYNC" << "Returncode =" << ret;   }   // 2
+        if ( ret == GST_STATE_CHANGE_NO_PREROLL ){ qDebug().noquote() << global::nameOutput << "Continue was clicked" << "GST_STATE_CHANGE_NO_PREROLL" << "Returncode =" << ret; }// 3
+
+        /* wait until it's up and running or failed */
+        if (gst_element_get_state (pipeline, NULL, NULL, -1) == GST_STATE_CHANGE_FAILURE) {
+          g_error ("Failed to go into PLAYING state");
+        } else {
+            qDebug().noquote() << global::nameOutput << "Continue was clicked";
+        }
+    }
+}
