@@ -8,16 +8,17 @@
 #include "QvkRegionChoise_wl.h"
 #include "QvkCountdown_wl.h"
 #include "QvkHelp_wl.h"
+#include "QvkSystray_wl.h"
 
 #include "QvkSpezialSlider.h"
 #include "QvkLogController.h"
 
 #include <QMainWindow>
+#include <QWidget>
 #include <QTranslator>
+#include <QStringList>
 #include <QFileSystemWatcher>
-#include <QScreen>
-#include <QThread>
-#include <QTime>
+#include <QCloseEvent>
 
 #include <gst/gst.h>
 
@@ -41,6 +42,7 @@ public:
     QvkSpezialSlider *sliderOpenh264;
     QvkSpezialSlider *sliderWaitBeforeSnapshot;
     QvkHelp_wl *vkHelp;
+    QvkSystray_wl *vkSystray;
 
 
 private:
@@ -60,14 +62,16 @@ private:
     void set_CornerWidget();
     void set_SpezialSliders();
     void set_Connects();
-    void set_check_all_Elements_available();
+    void set_check_screencast_elements_available();
+    void set_check_GIF_convert_elements_available();
+    void set_check_MP4_convert_elements_available();
+    void set_check_WEBM_convert_elements_available();
+
     void set_RegionChoice();
 
     void messageBox( QString value );
 
-    QString get_Videocodec_Encoder();
     QString get_Area_Videocrop();
-    QString get_Muxer();
     void get_system_info();
     QString get_KDE_Version();
     QString get_pipewire_version();
@@ -98,6 +102,9 @@ private Q_SLOTS:
     void slot_videoFileSystemWatcherSetNewPath();
     void slot_log_folder();
     void slot_log_refresh();
+    void slot_folder();
+    void slot_Pause();
+    void slot_Continue();
 
     // Snapshot
     void slot_snapshotHideBeforeRecording( bool bo );
@@ -106,8 +113,6 @@ private Q_SLOTS:
     void slot_path_to_snapshot_folder( bool bo );
     // Snapshot
 
-    void slot_videoCodecChanged( QString codec );
-
 
 protected:
     void closeEvent( QCloseEvent *event );
