@@ -23,6 +23,14 @@
 #include "QvkSettings_wl.h"
 #include "global.h"
 
+#include <QSettings>
+#include <QList>
+#include <QToolButton>
+#include <QRadioButton>
+#include <QCheckBox>
+#include <QSlider>
+#include <QComboBox>
+#include <QLineEdit>
 #include <QStandardPaths>
 
 QvkSettings_wl::QvkSettings_wl()
@@ -46,17 +54,24 @@ void QvkSettings_wl::readAll( Ui_formMainWindow_wl *ui_mainwindow, QMainWindow *
     for ( int i = 0; i < listToolButton.count(); i++ ) {
         // We found a setting, then we want set or not.
         QToolButton *toolButton = listToolButton.at(i);
+        // We have no settings-file(first start after install) but this object we want set as default.
+        if ( ( toolButton->objectName() == ui_mainwindow->toolButtonScreencast->objectName() ) and
+            ( settings.value( toolButton->objectName(), true ).toBool() == true ) ) {
+            toolButton->click();
+            continue;
+        }
+
+        if ( ( toolButton->objectName() == ui_mainwindow->toolButtonSnapshot->objectName() ) or
+             ( toolButton->objectName() == ui_mainwindow->toolButtonConvert->objectName() ) or
+             ( toolButton->objectName() == ui_mainwindow->toolButtonCamera->objectName() ) or
+             ( toolButton->objectName() == ui_mainwindow->toolButtonLog->objectName() )
+             ) {
+            ui_mainwindow->toolButtonScreencast->click();
+            continue;
+        }
+
         if ( settings.value( toolButton->objectName(), false ).toBool() == true ) {
-            // Toolbutton on Sidebar not clicked
-            if ( ( toolButton->objectName() == ui_mainwindow->toolButtonScreencast->objectName() ) or
-                 ( toolButton->objectName() == ui_mainwindow->toolButtonSnapshot->objectName() ) or
-                 ( toolButton->objectName() == ui_mainwindow->toolButtonCamera->objectName() ) or
-                 ( toolButton->objectName() == ui_mainwindow->toolButtonLog->objectName() )
-                 ) {
-                // do nothing
-            } else {
-                toolButton->click();
-            }
+            toolButton->click();
         }
     }
 
@@ -87,6 +102,17 @@ void QvkSettings_wl::readAll( Ui_formMainWindow_wl *ui_mainwindow, QMainWindow *
     QList<QSlider *> listSlider = ui_mainwindow->centralwidget->findChildren<QSlider *>();
     for ( int i = 0; i < listSlider.count(); i++ ) {
         QSlider *slider = listSlider.at(i);
+
+        if ( slider->objectName() == "sliderFrames" ) {
+            QVariant variant = settings.value( slider->objectName() );
+            if ( variant.isValid() ) {
+                slider->setValue( variant.toInt() );
+            } else {
+                slider->setValue( 25 );
+            }
+            continue;
+        }
+
         QVariant variant = settings.value( slider->objectName() );
         if ( variant.isValid() ) {
             slider->setValue( variant.toInt() );
